@@ -23,11 +23,13 @@ def serve(request, name):
     response['Content-Length'] = f.size
     return response
 
-def serve_mixed(request, name, document_root=None):
+def serve_mixed(request, *args, **kwargs):
     """
     First attempts to serve the file from the filesystem,
     then tries the database.
     """
+    name = kwargs.get('name') or kwargs.get('path')
+    document_root = kwargs.get('document_root')
     document_root = document_root or settings.MEDIA_ROOT
     try:
         # First attempt to serve from filesystem.
